tlslite.BaseDB.BaseDB

Package tlslite :: Module BaseDB :: Class BaseDB |
[show private | hide private]
[frames | no frames]

## Class BaseDB

Known Subclasses:
  `SharedKeyDB`, `VerifierDB`

Method Summary
| `__init__(self, filename, type)`
bool | ``__contains__`(self, username)` Check if the database contains the specified username.
| `__delitem__(self, username)`
| `__getitem__(self, username)`
| `__setitem__(self, username, value)`
| `check(self, username, param)`
| ``create`(self)` Create a new on-disk database.
list | ``keys`(self)` Return a list of usernames in the database.
| ``open`(self)` Open a pre-existing on-disk database.

Method Details

### __contains__(self, username) (In operator) Check if the database contains the specified username. Parameters: `username` - The username to check for. (type=str) Returns: True if the database contains the username, False otherwise. (type=bool)

### create(self) Create a new on-disk database. Raises: `anydbm.error` - If there's a problem creating the database.

### keys(self) Return a list of usernames in the database. Returns: The usernames in the database. (type=list)

### open(self) Open a pre-existing on-disk database. Raises: `anydbm.error` - If there's a problem opening the database. `ValueError` - If the database is not of the right type.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net